package com.example.molinobd;

import java.util.List;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;

import com.google.android.maps.Overlay;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Point;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Toast;

public class MapaActivity extends MapActivity implements OnClickListener  {
	private static final String DEBUG_TAG="Warning";
	
	// Permitir mostrar el mapa
	private MapView mapView;
	// Permitir controlar ciertas caractersticas del mapView
	private MapController controller;
	// Contendr el URI geogrfico
	private GeoPoint geoPoint;
	// URI geogrfico: 
	public String strLatitud; 
	public String strLongitud; 
	
	// Se ejecuta cuando la actividad es llamada por primara vez.
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_mapa);
        
        // Recuperar parmetros
        strLatitud = getIntent().getStringExtra("strLatitud");
        strLongitud = getIntent().getStringExtra("strLongitud");
        
        // Se verifica que los parmetros pasados sean correctos
        Log.w(DEBUG_TAG, "Warning: Datos GPS: [[[[" + strLatitud + ":" + strLongitud + "]]]] ");
        
        // Obtener el mapa del layout 
        mapView = (MapView) findViewById(R.id.mapview);
        // Permitir el control de Zoom
        mapView.setBuiltInZoomControls(true); 
        // Permitir visulizacin como foto satlite, en vez de un mapa.
        mapView.setSatellite(true);
        // Inicializar el controllador del mapView, que se utiliza en onClick
        controller = mapView.getController();

    	// Posicionar segn URI geogrfico. 
    	irURIGeografico();
    	
    	
    }
   
    // Capturar evento click 
    public void onClick(View v) {
    	// Reposicionar segn nueva URI geogrfico. 
    	// irURIGeografico(strLatitud, strLongitud);
    	
    }
    
    // Mtodo obligatorio, ya que Google Maps necesita conocer si 
    // se muestra alguna informacin de ruta en el mapa. 
    // Por defecto se le indica false.
    @Override
    protected boolean isRouteDisplayed() {
        return false;
    }
    
    // Dibujar un indicador para indicar la posicin sobre el mapa.
    private void drawPushpin(){
    	
    	MapOverlay mapOverlay = new MapOverlay();
        List<Overlay> listOfOverlays = mapView.getOverlays();
        listOfOverlays.clear();
        listOfOverlays.add(mapOverlay);        
 

    }

    // Clase Overlay, utilizada por drawPushpin()
    class MapOverlay extends com.google.android.maps.Overlay
    {
        //@Override
        public boolean draw(Canvas canvas, MapView mapView, 
        boolean shadow, long when) 
        {
            super.draw(canvas, mapView, shadow);                   
 
            //---convierte el GeoPoint a pixeles---
            Point screenPts = new Point();
            mapView.getProjection().toPixels(geoPoint, screenPts);
 
            //---Agrega el marcador---
            Bitmap bmp = BitmapFactory.decodeResource(
                getResources(), R.drawable.pushpin);       
            	// getResources(), R.drawable.ic_location_place);
            canvas.drawBitmap(bmp, screenPts.x, screenPts.y-50, null);         
            return true;
        }
    } 
    
    // Mtodo que se posiciona en el URI geogrfico pasado por parmetro
    private void irURIGeografico() {   	
        try {
        	// Parsear valores lat/long
        	int latE6 =  Integer.parseInt(strLatitud);
        	int lonE6 = Integer.parseInt(strLongitud);
        	// Especificar en geoPoint las coordenadas
        	geoPoint = new GeoPoint(latE6 , lonE6 );
        	
            // Se verifica que los parmetros pasados sean correctos
            Log.w(DEBUG_TAG, "Warning: Datos GPS: [[[[" + latE6  + ":" + lonE6  + "]]]] ");
            // Se informa 'fugasmente' de la GEO localizacin
        	Toast.makeText(this, getResources().getString(R.string.strGPS) + " [" + latE6  + ":" + lonE6  + "] ", Toast.LENGTH_LONG).show();
        	
        	// Animar el mapa para que se traslada al geoPoint.
        	controller.animateTo(geoPoint);
        	// Establecer el nive lde zoom a 13, 
        	// variando de cero a 19 en vista mapa
        	// o a 22 en vista de satlite ( Que es nuestro caso )
        	controller.setZoom(18);
        	// Establecer las coordenadas a mostrar
        	controller.setCenter(geoPoint);
            // Dibujar un "Pushpin" en la posicion exacta dadas por las coordenadas
            this.drawPushpin(); 
            
            
        	mapView.invalidate();
        	
        } catch (Exception e) {
        	Toast.makeText(this, getResources().getString(R.string.coordenadas_invalidas), Toast.LENGTH_LONG).show();
        }
    }
    
    
    

    
}